==> openshift-model-operatorhub-5.12.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SpecDescriptorBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SpecDescriptorBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptorFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptor,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptorBuilder>{
  public SpecDescriptorBuilder() {
    this(false);
  }
  public SpecDescriptorBuilder(java.lang.Boolean validationEnabled) {
    this(new SpecDescriptor(), validationEnabled);
  }
  public SpecDescriptorBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptorFluent<?> fluent) {
    this(fluent, false);
  }
  public SpecDescriptorBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SpecDescriptor(), validationEnabled);
  }
  public SpecDescriptorBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptorFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptor instance) {
    this(fluent, instance, false);
  }
  public SpecDescriptorBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptorFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptor instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDisplayName(instance.getDisplayName()); 
    fluent.withPath(instance.getPath()); 
    fluent.withValue(instance.getValue()); 
    fluent.withXDescriptors(instance.getXDescriptors()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SpecDescriptorBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptor instance) {
    this(instance,false);
  }
  public SpecDescriptorBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptor instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withPath(instance.getPath()); 
    this.withValue(instance.getValue()); 
    this.withXDescriptors(instance.getXDescriptors()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SpecDescriptor build() {
    SpecDescriptor buildable = new SpecDescriptor(fluent.getDescription(),fluent.getDisplayName(),fluent.getPath(),fluent.getValue(),fluent.getXDescriptors());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SpecDescriptorBuilder that = (SpecDescriptorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-6.5.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SpecDescriptorBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SpecDescriptorBuilder extends SpecDescriptorFluentImpl<SpecDescriptorBuilder> implements VisitableBuilder<SpecDescriptor,SpecDescriptorBuilder>{
  public SpecDescriptorBuilder() {
    this(false);
  }
  public SpecDescriptorBuilder(Boolean validationEnabled) {
    this(new SpecDescriptor(), validationEnabled);
  }
  public SpecDescriptorBuilder(SpecDescriptorFluent<?> fluent) {
    this(fluent, false);
  }
  public SpecDescriptorBuilder(SpecDescriptorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SpecDescriptor(), validationEnabled);
  }
  public SpecDescriptorBuilder(SpecDescriptorFluent<?> fluent,SpecDescriptor instance) {
    this(fluent, instance, false);
  }
  public SpecDescriptorBuilder(SpecDescriptorFluent<?> fluent,SpecDescriptor instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDisplayName(instance.getDisplayName()); 
    fluent.withPath(instance.getPath()); 
    fluent.withValue(instance.getValue()); 
    fluent.withXDescriptors(instance.getXDescriptors()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SpecDescriptorBuilder(SpecDescriptor instance) {
    this(instance,false);
  }
  public SpecDescriptorBuilder(SpecDescriptor instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withPath(instance.getPath()); 
    this.withValue(instance.getValue()); 
    this.withXDescriptors(instance.getXDescriptors()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  SpecDescriptorFluent<?> fluent;
  Boolean validationEnabled;
  public SpecDescriptor build() {
    SpecDescriptor buildable = new SpecDescriptor(fluent.getDescription(),fluent.getDisplayName(),fluent.getPath(),fluent.getValue(),fluent.getXDescriptors());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
